#!/bin/bash
#====================================================================================
#RTH sample using CURL (https://curl.haxx.se/)
#====================================================================================
#Retrieve and save the latest set of extraction files for a named RTH schedule.
#Display contents of the notes files.

#Pre-requisite: a pre-existing schedule (it can be created manually, or using the API).

#Typical use case: regular retrieval of extraction files generated by a recurring schedule.
#Example:
# - A manually created daily schedule is set to run every day at 1 am.
# - This sample runs every day at 3 am to retrieve the generated files.

#The extraction file set typically contains:
# - The "Full" file, containing the requested data
# - The "Note" file, containing extraction notes, warnings and errors
# - The "RicMaintenanceNote" file, containing information on RIC name changes;
#   it is generated (or not) based on a setting in the user preferences, in the GUI.

#The extraction file compression is defined in the report template.
#It can be:
# - None: delivers a text file with extension .csv
# - ZIP:  delivers a zipped text file with extension .zip
# - GZIP: delivers a gzipped text file with extension .gz
#The selected compression is applied to the "Full" and "RicMaintenanceNote" files.
#The "Note" file is always a text file with extension .txt
#When creating a report template with the:
# - API: default compression settings are applied, based on the template type.
# - GUI: settings are done manually, with restictions based on the template type.
#This demo code handles all these compression settings.
#====================================================================================

#Set these parameters before running the code
filePath="./"
myScheduleName="myScheduleName"
myUsername="myUsername"
myPassword="myPassword"
useAws=true

#Get authentication token
out=$(curl -s -H "Content-Type:application/json" -d "{ \"Credentials\": {\"Username\": \"$myUsername\", \"Password\": \"$myPassword\" }}" -X POST "https://selectapi.datascope.refinitiv.com/RestApi/v1/Authentication/RequestToken")
token=$(echo $out | awk -F "\"" '{print $8}')
if [ ! "$token" ]
then
   echo "Could not retrieve token, check your user name and password".
   exit 1
fi
#For debugging:
echo $token

#Get schedule ID (from name)
out=$(curl -s -H "Content-Type:application/json" -H "Authorization:Token $token" -X GET "https://selectapi.datascope.refinitiv.com/RestApi/v1/Extractions/ScheduleGetByName(ScheduleName='$myScheduleName')")
scheduleID=$(echo $out | awk -F "\"" '{print $8}')
if [ ! "$scheduleID" ]
then
   echo "Could not retrieve schedule ID, check your schedule name".
   exit 2
fi
#For debugging:
echo $scheduleID

#Get report extraction ID for last extraction (from schedule ID)
out=$(curl -s -H "Content-Type:application/json" -H "Authorization:Token $token" -X GET "https://selectapi.datascope.refinitiv.com/RestApi/v1/Extractions/Schedules('$scheduleID')/LastExtraction")
reportID=$(echo $out | awk -F "\"" '{print $8}')
if [ ! "$reportID" ]
then
   echo "Could not retrieve report ID, use the GUI to check if your schedule has run at least once".
   exit 3
fi
#For debugging:
echo $reportID

#Get report file list, with for each file its ID, type, name and size (from the report ID)
out=$(curl -s -H "Content-Type:application/json" -H "Authorization:Token $token" -X GET "https://selectapi.datascope.refinitiv.com/RestApi/v1/Extractions/ReportExtractions('$reportID')/Files")
reportExtractionsResult=$(echo $out | awk -F "[" '{print $2}')
if [ ! "$reportExtractionsResult" ]
then
   echo "Could not retrieve report extraction result, use the GUI to check your schedule status".
   exit 4
fi

#File 1: get details:
reportFileResult1=$(echo $reportExtractionsResult| awk -F "{" '{print $2}')
if [ "$reportFileResult1" ]; then
  extractedFileID=$(echo $reportFileResult1 | awk -F "\"" '{print $4}')
  extractedFileType=$(echo $reportFileResult1 | awk -F "\"" '{print $16}')
  extractedFileName=$(echo $reportFileResult1 | awk -F "\"" '{print $20}')
  extractedFileSize=$(echo $reportFileResult1 | awk -F "\"" '{print $29}'| awk -F ":" '{print $2}'| awk -F "," '{print $1}'| awk -F "}" '{print $1}')
  #For debugging:
  echo "File 1 | ID:" $extractedFileID "- Type:" $extractedFileType "- Name:"  $extractedFileName "- Size:" $extractedFileSize
  #File 1: download:
  fullFileName=$filePath$extractedFileName
  echo "Download file: " $fullFileName
  curl -s -H "Authorization:Token $token" -X GET "https://selectapi.datascope.refinitiv.com/RestApi/v1/Extractions/ExtractedFiles('$extractedFileID')/\$value" -o $fullFileName
  #For debugging:
  ls -l $fullFileName
fi

#File 2: get details:
reportFileResult2=$(echo $reportExtractionsResult| awk -F "{" '{print $3}')
if [ "$reportFileResult2" ]; then
  extractedFileID=$(echo $reportFileResult2 | awk -F "\"" '{print $4}')
  extractedFileType=$(echo $reportFileResult2 | awk -F "\"" '{print $16}')
  extractedFileName=$(echo $reportFileResult2 | awk -F "\"" '{print $20}')
  extractedFileSize=$(echo $reportFileResult2 | awk -F "\"" '{print $29}'| awk -F ":" '{print $2}'| awk -F "," '{print $1}'| awk -F "}" '{print $1}')
  #For debugging:
  echo "File 2 | ID:" $extractedFileID "- Type:" $extractedFileType "- Name:"  $extractedFileName "- Size:" $extractedFileSize
  #File 2: download:
  fullFileName=$filePath$extractedFileName
  echo "Download file: " $fullFileName
  curl -s -H "Authorization:Token $token" -X GET "https://selectapi.datascope.refinitiv.com/RestApi/v1/Extractions/ExtractedFiles('$extractedFileID')/\$value" -o $fullFileName
  #For debugging:
  ls -l $fullFileName
fi

#File 3: get details:
reportFileResult3=$(echo $reportExtractionsResult| awk -F "{" '{print $4}')
if [ "$reportFileResult3" ]; then
  extractedFileID=$(echo $reportFileResult3 | awk -F "\"" '{print $4}')
  extractedFileType=$(echo $reportFileResult3 | awk -F "\"" '{print $16}')
  extractedFileName=$(echo $reportFileResult3 | awk -F "\"" '{print $20}')
  extractedFileSize=$(echo $reportFileResult3 | awk -F "\"" '{print $29}'| awk -F ":" '{print $2}'| awk -F "," '{print $1}'| awk -F "}" '{print $1}')
  #For debugging:
  echo "File 3 | ID:" $extractedFileID "- Type:" $extractedFileType "- Name:"  $extractedFileName "- Size:" $extractedFileSize
  #File download:
  fullFileName=$filePath$extractedFileName
  echo "Download file: " $fullFileName
  curl -s -H "Authorization:Token $token" -X GET "https://selectapi.datascope.refinitiv.com/RestApi/v1/Extractions/ExtractedFiles('$extractedFileID')/\$value" -o $fullFileName
  #For debugging:
  ls -l $fullFileName
fi
